import { IResource as IResourceBase, Resource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { ResourceOptions } from './resource';
import { RestApi } from './restapi';
/**
 * API keys are alphanumeric string values that you distribute to app developer customers to grant access to your API.
 */
export interface IApiKey extends IResourceBase {
    /**
     * The API key ID.
     *
     * @attribute true
     */
    readonly keyId: string;
}
/**
 * The options for creating an API Key.
 */
export interface ApiKeyOptions extends ResourceOptions {
    /**
     * A name for the API key.
     *
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the API key name.
     *
     * @default automically generated name
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-name
     */
    readonly apiKeyName?: string;
    /**
     * The value of the API key.
     *
     * Must be at least 20 characters long.
     *
     * @default none
     * @link https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-value
     */
    readonly value?: string;
}
/**
 * ApiKey Properties.
 */
export interface ApiKeyProps extends ApiKeyOptions {
    /**
     * [disable-awslint:ref-via-interface] A list of resources this api key is associated with.
     *
     * @default none
     */
    readonly resources?: RestApi[];
    /**
     * An AWS Marketplace customer identifier to use when integrating with the AWS SaaS Marketplace.
     *
     * @default none
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-customerid
     */
    readonly customerId?: string;
    /**
     * A description of the purpose of the API key.
     *
     * @default none
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-description
     */
    readonly description?: string;
    /**
     * Indicates whether the API key can be used by clients.
     *
     * @default true
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-enabled
     */
    readonly enabled?: boolean;
    /**
     * Specifies whether the key identifier is distinct from the created API key value.
     *
     * @default false
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-generatedistinctid
     */
    readonly generateDistinctId?: boolean;
}
/**
 * An API Gateway ApiKey.
 *
 * An ApiKey can be distributed to API clients that are executing requests
 * for Method resources that require an Api Key.
 */
export declare class ApiKey extends Resource implements IApiKey {
    /**
     * Import an ApiKey by its Id.
     */
    static fromApiKeyId(scope: Construct, id: string, apiKeyId: string): IApiKey;
    /**
     * The API key ID.
     */
    readonly keyId: string;
    /**
     *
     */
    constructor(scope: Construct, id: string, props?: ApiKeyProps);
    private renderStageKeys;
}
